# resolvconf Cookbook

This cookbook maintains /etc/resolv.conf using the resolvconf package, which is installed by default on Debian/Ubuntu.

## Requirements

A system that supports resolvconf.

- Ubuntu >= 10.04
- Debian >= 6.0

Furthermore you need to add the following line to your metadata.rb

```ruby
depends 'resolvconf'
```


## Attributes

This section describes the supported attributes, as well as their default settings.

Use the following attributes to specify your nameserver(s) to use, the search domain(s) and additional options.
Each attribute supports strings, as well as arrays with multiple elements.

```ruby
node['resolvconf']['nameserver'] = %w(208.67.222.222 208.67.220.220) # Set nameserver(s) to use
node['resolvconf']['search'] = node['domain'] # Set domains to search
node['resolvconf']['options'] = [] # Set options
node['resolvconf']['sortlist'] = ['130.155.160.0/255.255.240.0 130.155.0.0'] # Default is empty
```


These attributes specify strings that are included in /etc/resolv.conf at head/body/tail.

```ruby
node['resolvconf']['head'] = [
  '# Dynamic resolv.conf(5) file for glibc resolver(3) generated by resolvconf(8)',
  '#     DO NOT EDIT THIS FILE BY HAND -- YOUR CHANGES WILL BE OVERWRITTEN'
]
node['resolvconf']['base'] = []
node['resolvconf']['tail'] = []
```


By default, the recipe removes any dns-\* configuration lines from /etc/network/interfaces,
as they might interferre with the configured settings.

```ruby
node['resolvconf']['clear-dns-from-interfaces'] = true
```

You can force the resolvconf cookbook to wipe old entries from the runtime directories. Use this if
you have trouble with old resolv.conf entries ending up in your configuration.
This is not enabled by default, as it removes the dynamic capabilities of resolvconf which enable
applications to change nameserver settings on the fly.

```ruby
node['resolvconf']['wipe-runtime-directory'] = false
```
You can set a list of interfaces that you want to inherit the dns settings from. It creates the 
interface-order file /etc/resolvconf/interface-order and builds it from the list.
This enables you to control which additional dns servers if any are added from which interfaces.
```ruby
node['resolvconf']['interface-order'] = [
  'lo.inet*',
  'lo.dnsmasq',
  'lo.pdnsd',
  'lo.!(pdns|pdns-recursor)',
  'lo',
  'tun*',
  'tap*',
  'hso*',
  'em+([0-9])?(_+([0-9]))*',
  'p+([0-9])p+([0-9])?(_+([0-9]))*',
  'eth*',
  'ath*',
  'wlan*',
  'ppp*',
  '*'
]
```


## Provider

### resolvconf

The LWRP basically supports all options that can be set via attributes, and uses the same defaults.
It will do the following

- It will create the necessary files in /etc/resolvconf/resolv.conf.d/
- Remove dns-\* lines from /etc/network/interfaces (unless `clear_dns_form_interfaces` is specified)
- Run 'resolvconf -u'

Before using the provider, you probably want to ensure that the resolvconf package is installed.

```ruby
include_recipe 'resolvconf::install'
```

Example:

```ruby
resolvconf 'default'
```

```ruby
resolvconf 'custom' do
  nameserver '8.8.8.8'
  search     'mydomain.com'
  options    'rotate'
  sortlist   'mysortlist'

  head       "# Don't touch this configuration file!"
  base       "# Will be added after nameserver, search, options config items"
  tail       "# This goes to the end of the file."

  # do not touch my interface configuration plz!
  clear_dns_from_interfaces false
end
```


## Recipes

### resolvconf:install

Installs the resolvconf package.


### resolvconf::default

Includes resolvconf::install, then configures the node using the specified attributes / defaults.



# Contributing

Contributions are very welcome!

1. Fork the repository on Github
2. Create a named feature branch (like `add_component_x`)
3. Write you change
4. Write tests for your change (if applicable)
5. Run the tests, ensuring they all pass
6. Submit a Pull Request using Github


# License and Authors

Authors: Chris Aumann <me@chr4.org>

License: GPLv3
